Crate rustest_fixtures

Crate rustest_fixtures 

This crate is a set of standard fixtures for rustest.

This crate is pretty young and a the number of fixture is small. If you have a need for new standard fixture, issue or PR are welcomed.

Structs

Global
Transform a fixture into a global fixture.
TempDir
A temporary directory.
TempFile
A temporary file.